load_map

Function load_map 

pub fn load_map(
    data: &str,
    textures: &[(&str, Texture2D)],
    external_tilesets: &[(&str, &str)],
) -> Result<Map, Error>
Load Tiled tile map from given json string. “data” is a tiled json content. “textures” is a map from the name used in the json to macroquad texture. “external_tilesets” is a map of tileset name to tileset json content. “external_tilesets” is used when in tiled the “source” field is used instead of embedded tileset.